==> charge-c-base-1.0-20230606.100520-42-sources.jar: com/rocogz/syy/charge/entity/ChargeDetail.java <==
package com.rocogz.syy.charge.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.TableName;
import com.rocogz.syy.charge.constant.ChargeConstant;
import com.rocogz.syy.common.entity.IdEntity;
import lombok.Data;
import lombok.experimental.Accessors;

/**
 * @Description: C端充电明细表
 * @date：2023/02/27
 * @author：
 */
@Data
@Accessors(chain = true)
@TableName("charge_detail")
public class ChargeDetail extends IdEntity {

    private static final long serialVersionUID = 710576143185164474L;

    /**
    * 明细编号
    */
    private String code;

    /**
    * 批次号
    */
    private String batchNo;

    /**
    * 流水号
    */
    private String turnoverCode;
    
    /**
    * 卡号
    */
    private String accountCode;
    
    /**
    * 手机号
    */
    private String mobile;
    
    /**
    * 类型（字典，字典编号：CHARGE_DETAIL_TYPE）
     * @see ChargeConstant.DetailType
    */
    private String type;
    
    /**
    * 状态（字典，字典编号：CHARGE_DETAIL_STATUS）
     * @see ChargeConstant.DetailStatus
    */
    private String status;
    
    /**
    * 总额度
    */
    private BigDecimal totalQuota;
    
    /**
    * 可用额度
    */
    private BigDecimal availableQuota;
    
    /**
    * 已用额度
    */
    private BigDecimal usedQuota;
    
    /**
    * 生效日期
    */
    private LocalDateTime effctiveDate;
    
    /**
    * 失效日期
    */
    private LocalDateTime expireDate;
    
    /**
    * 来源小程序miniAppId
    */
    private String miniAppId;

    /**
    * 来源平台
    */
    private String sourcePlatform;

    /**
     * 上游订单编号
     */
    private String orderCode;

    /**
     * 余额是否全部用完
     */
    public boolean isQuotaUsed(){
        return BigDecimal.ZERO.compareTo(this.availableQuota) >= 0;
    }
}

==> charge-c-base-1.0-20230829.062723-50-sources.jar: com/rocogz/syy/charge/entity/ChargeDetail.java <==
package com.rocogz.syy.charge.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.TableName;
import com.rocogz.syy.charge.constant.ChargeConstant;
import com.rocogz.syy.common.entity.IdEntity;
import lombok.Data;
import lombok.experimental.Accessors;

/**
 * @Description: C端充电明细表
 * @date：2023/02/27
 * @author：
 */
@Data
@Accessors(chain = true)
@TableName("charge_detail")
public class ChargeDetail extends IdEntity {

    private static final long serialVersionUID = 710576143185164474L;

    /**
    * 明细编号
    */
    private String code;

    /**
    * 批次号
    */
    private String batchNo;

    /**
    * 流水号
    */
    private String turnoverCode;
    
    /**
    * 卡号
    */
    private String accountCode;
    
    /**
    * 手机号
    */
    private String mobile;
    
    /**
    * 类型（字典，字典编号：CHARGE_DETAIL_TYPE）
     * @see ChargeConstant.DetailType
    */
    private String type;
    
    /**
    * 状态（字典，字典编号：CHARGE_DETAIL_STATUS）
     * @see ChargeConstant.DetailStatus
    */
    private String status;
    
    /**
    * 总额度
    */
    private BigDecimal totalQuota;
    
    /**
    * 可用额度
    */
    private BigDecimal availableQuota;
    
    /**
    * 已用额度
    */
    private BigDecimal usedQuota;
    
    /**
    * 生效日期
    */
    private LocalDateTime effctiveDate;
    
    /**
    * 失效日期
    */
    private LocalDateTime expireDate;
    
    /**
    * 来源小程序miniAppId
    */
    private String miniAppId;

    /**
    * 来源平台
    */
    private String sourcePlatform;

    /**
     * 上游订单编号
     */
    private String orderCode;

    /**
     * 是否已经有使用过
     * 只要已使用大于0就是用过了
     */
    public boolean hasUsed(){
        return BigDecimal.ZERO.compareTo(this.usedQuota) < 0;
    }

    /**
     * 余额是否全部用完
     * 只要可用小于等于0就是全部用完
     */
    public boolean isQuotaUsed(){
        return BigDecimal.ZERO.compareTo(this.availableQuota) >= 0;
    }
}
